<?php
if ( ! defined( 'ABSPATH' ) ) { exit; }

/* **************************************************************************************
  Custom Controls
************************************************************************************** */
if ( ! function_exists( 'swm_add_customizer_custom_controls' ) ) {
    function swm_add_customizer_custom_controls( $wp_customize ) {

        if ( !class_exists( 'swm_Customize_Control_Textarea' ) ) {
            class swm_Customize_Control_Textarea extends WP_Customize_Control {
                public $type = 'textarea';
                public function render_content() {
                    ?>
                    <label>
                        <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                        <textarea <?php $this->link(); ?> rows="10" style="width: 98%;"><?php echo esc_textarea( $this->value() ); ?></textarea>
                    </label>
                    <?php
                }
            }
        }

        if ( !class_exists( 'swm_Customize_Control_Multicheck' ) ) {
            class swm_Customize_Control_Multicheck extends WP_Customize_Control {
                public $type = 'multi-check';
                public function render_content() {
                    ?>
                    <label>
                        <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                        <small><?php echo esc_html( $this->description ); ?></small><br/><br/>
                    </label>

                    <?php $multi_values = !is_array( $this->value() ) ? explode( ',', $this->value() ) : $this->value(); ?>

                    <ul>
                        <?php foreach ( $this->choices as $value => $label ) : ?>

                            <li>
                                <label>
                                    <input type="checkbox" value="<?php echo esc_attr( $value ); ?>" <?php checked( in_array( $value, $multi_values ) ); ?> />
                                    <?php echo esc_html( $label ); ?>
                                </label>
                            </li>

                        <?php endforeach; ?>
                    </ul>

                    <input type="hidden" <?php $this->link(); ?> value="<?php echo esc_attr( implode( ',', $multi_values ) ); ?>" />

                    <?php
                }
            }
        }

        if ( !class_exists( 'swm_Customize_Control_Select_Sections' ) ) {
            class swm_Customize_Control_Select_Sections extends WP_Customize_Control {

                public $type = 'select-section';

                public function render_content() {

                    if ( empty( $this->choices ) ) {
                        $swmCustomSectionInfo_start = '<a href="post-new.php?post_type=cpt_sections" target="_blank">';
                        $swmCustomSectionInfo_end = '</a>';

                        echo '<p class="red">' . sprintf( esc_html__( 'Section doesn\'t exist. Create section from Admin > Sections > %sAdd New%s', 'studio-fifty' ),$swmCustomSectionInfo_start, $swmCustomSectionInfo_end) . '</p>';
                        return;
                    }
                    ?>
                        <label>
                            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                            <select <?php $this->link(); ?> name=<?php echo '_customize-input-' . $this->id; ?> id="<?php echo '_customize-input-' . $this->id; ?>">
                                <?php
                                    foreach ($this->choices as $key => $item){

                                        $page_style = get_theme_mod($this->id, '0');

                                        if(isset($page_style) && $key == $page_style) {
                                            $css_string = 'selected';
                                        } else {
                                            $css_string = '';
                                        }

                                        echo '<option class="'.$page_style.'" value="'.$key.'" ' . selected( $page_style, $key, false ) . ' >'.$item.'</option>';
                                    }

                                ?>
                            </select>
                            <p><?php echo wp_kses( $this->description,swm_kses_allowed_textarea() ); ?></p>
                        </label>
                    <?php
                }
            }
        }

        if ( !class_exists( 'swm_Customize_Slider_Control' ) ) {
            class swm_Customize_Slider_Control extends WP_Customize_Control {
                public $type = 'slider';

                public function render_content() { ?>
                    <div class="swm-customizer-slider-control">
                        <label>
                            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                        </label>
                        <div class="left">
                            <input type="range" name="points" min="<?php echo esc_attr($this->choices['min']); ?>" max="<?php echo esc_attr($this->choices['max']); ?>" value="<?php echo floatval( $this->value() ); ?>" step="<?php echo esc_attr($this->choices['step']); ?>" <?php $this->link(); ?>>
                        </div>
                        <div class="right">
                            <input class="swm_customizer_slider_value" name="<?php echo esc_attr( $this->id ); ?>" type="number" <?php $this->link(); ?> value="<?php echo floatval( $this->value() ); ?>" />
                            <div class="swm_customizer_slider"></div>
                        </div>
                        <div class="clear"></div>
                    </div>
                <?php
                }
            }
        }

        if ( !class_exists( 'swm_Customize_Radio_Image_Control' ) ) {
            class swm_Customize_Radio_Image_Control extends WP_Customize_Control {

                public $type = 'radio-image';

                public function render_content() {

                    if ( empty( $this->choices ) ) {
                        return;
                    }

                    $name = '_customize-radio-'.$this->id;

                    ?>
                    <span class="customize-control-title">
                        <?php echo esc_html( $this->label ); ?>
                    </span>
                    <div id="input_<?php echo esc_attr( $this->id ); ?>" class="image swmCustButtonImage">
                        <?php foreach ( $this->choices as $value => $label ) : ?>

                            <input class="image-select" type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" id="<?php echo esc_attr( $this->id ).esc_attr( $value ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?>>
                                <label for="<?php echo esc_attr( $this->id ).esc_attr( $value ); ?>">
                                    <img src="<?php echo esc_url( $label ); ?>" rel="tooltip" class="<?php echo esc_attr( $this->id ).'_'.esc_attr( $value ); ?>">
                                </label>
                            </input>

                        <?php endforeach; ?>
                    </div>
                    <?php
                }

            }
        }

        if ( !class_exists( 'swm_Customize_Radio_Switch_Control' ) ) {
            class swm_Customize_Radio_Switch_Control extends WP_Customize_Control {

                public $type = 'radio-switch';

                public function render_content() {

                    $name = '_customize-radio-'.$this->id;
                    ?>

                    <div id="input_<?php echo esc_attr( $this->id ); ?>" class="image swm-image-switch">

                        <div class="swm-image-switch-block">
                            <input class="image-select" type="radio" value="on" name="<?php echo esc_attr( $name ); ?>" id="<?php echo esc_attr( $this->id ).'-on'; ?>" <?php $this->link(); checked( $this->value(), 'on' ); ?>>
                                <label for="<?php echo esc_attr( $this->id ).'-on'; ?>">
                                   <p rel="tooltip" title="On" class="mode-on"></p>
                                </label>
                            </input>

                             <input class="image-select" type="radio" value="off" name="<?php echo esc_attr( $name ); ?>" id="<?php echo esc_attr( $this->id ).'-off'; ?>" <?php $this->link(); checked( $this->value(), 'off' ); ?>>
                                <label for="<?php echo esc_attr( $this->id ).'-off'; ?>">
                                    <p rel="tooltip" title="Off" class="mode-off"></p>
                                </label>
                            </input>
                        </div>

                        <div class="swm-image-switch-title">
                            <span><?php echo esc_html( $this->label ); ?></span>
                        </div>

                    </div>

                    <?php
                }

            }
        }

        if ( !class_exists( 'swm_Customize_Buttontab_Control' ) ) {
            class swm_Customize_Buttontab_Control extends WP_Customize_Control {
                public $type = 'buttontab';

                public function enqueue() {
                    wp_enqueue_script( 'jquery-ui-button' );
                }

                protected function render() {
                    $id    = 'customize-control-' . str_replace( '[', '-', str_replace( ']', '', esc_attr( $this->id ) ) );
                    $class = 'customize-control customize-control-buttonset ';

                    ?><li id="<?php echo esc_attr( $id ); ?>" class="<?php echo esc_attr( $class ); ?>">
                        <?php $this->render_content(); ?>
                    </li><?php
                }

                protected function render_content() {
                    if ( empty( $this->choices ) ) {
                        return;
                    }

                    $name = '_customize-radio-' . esc_attr( $this->id );
                    $swm_button_count = 1;
                    ?>
                    <div id="input_<?php echo esc_attr( $this->id ); ?>" class="swm-control-buttonset">

                        <?php if ( ! empty( $this->label ) ) : ?>
                            <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
                        <?php endif; ?>

                        <div class="swm-buttonset">
                            <?php
                                foreach ( $this->choices as $value => $label ) : ?>
                                    <input type="radio" value="<?php echo esc_attr( $value ); ?>" name="<?php echo esc_attr( $name ); ?>" id="<?php echo esc_attr( $this->id . $value ); ?>" <?php $this->link(); checked( $this->value(), esc_attr( $value ) ); ?> />
                                    <label for="<?php echo esc_attr( $this->id ) . $value; ?>" class="bt_count<?php echo esc_attr($swm_button_count); ?>">
                                        <?php echo esc_html( $label ); ?>
                                    </label>
                                    <?php
                                    $swm_button_count++;

                                endforeach;
                            ?>
                            <div class="clear"></div>
                        </div>

                    </div>
                <?php
                }
            }
        }

        if ( !class_exists( 'swm_Customize_Sidebar_Control' ) ) {
            class swm_Customize_Sidebar_Control extends WP_Customize_Control {

                private $posts = false;

                public function __construct($manager, $id, $args = array(), $options = array()) {
                    $postargs = wp_parse_args($options, array('numberposts' => '100'));
                    $this->posts = get_posts($postargs);

                    parent::__construct( $manager, $id, $args );
                }

                public function render_content() {

                    global $post;
                    $post_id = $post;
                    if (is_object($post_id)) {
                        $post_id = $post_id->ID;
                    }
                    $swm_selected_sidebar = get_post_meta($post_id, 'sbg_selected_sidebar', true);
                    if(!is_array($swm_selected_sidebar)){
                        $tmp = $swm_selected_sidebar;
                        $swm_selected_sidebar = array();
                        $swm_selected_sidebar[0] = $tmp;
                    }
                    $swm_selected_sidebar_replacement = get_post_meta($post_id, 'sbg_selected_sidebar_replacement', true);
                    if(!is_array($swm_selected_sidebar_replacement)){
                        $tmp = $swm_selected_sidebar_replacement;
                        $swm_selected_sidebar_replacement = array();
                        $swm_selected_sidebar_replacement[0] = $tmp;
                    }

                    ?>
                    <label>
                        <span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span> <?php
                       global $wp_registered_sidebars;
                       ?>

                            <select name="sidebar_generator" style="display: none;" >
                                <option value="0"<?php if($swm_selected_sidebar == ''){ echo " selected";} ?>>WP Default Sidebar</option>
                            <?php
                            $sidebars = $wp_registered_sidebars;
                            if(is_array($sidebars) && !empty($sidebars)){
                                foreach($sidebars as $sidebar){
                                    if($swm_selected_sidebar == $sidebar['id']){
                                        echo "<option value='{$sidebar['id']}' selected>{$sidebar['name']}</option>\n";
                                    }else{
                                        echo "<option value='{$sidebar['id']}'>{$sidebar['name']}</option>\n";
                                    }
                                }
                            }
                            ?>
                            </select>
                            <select id="sidebar_generator_replacement" <?php $this->link(); ?> >

                            <?php
                            $swm_sidebar_replacements = $wp_registered_sidebars;
                            if(is_array($swm_sidebar_replacements) && !empty($swm_sidebar_replacements)){
                                foreach($swm_sidebar_replacements as $sidebar){
                                    if($swm_selected_sidebar_replacement == $sidebar['id']){
                                        echo "<option value='{$sidebar['id']}' selected>{$sidebar['name']}</option>\n";
                                    }else{
                                        echo "<option value='{$sidebar['id']}'>{$sidebar['name']}</option>\n";
                                    }
                                }
                            }
                            ?>
                            </select>

                    </label>
                        <?php
                }
            }
        }


    }
    add_action( 'customize_register', 'swm_add_customizer_custom_controls' );
}