<?php

/* ----------------------------------------------------------------------------------------
    Page Title
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_get_main_titles_text')) {
    function swm_get_main_titles_text() {

        global  $wp_query;
        $swm_main_title = '';

        if ( is_archive() ) {

            if ( is_day() ) {
                $swm_main_title = sprintf( esc_html__( 'Archive: %s', 'studio-fifty' ), get_the_date() );
            }
            elseif ( is_month() ) {
                $swm_main_title = sprintf( esc_html__( 'Archive: %s', 'studio-fifty' ), get_the_date('F Y') );
            }
            elseif ( is_year() ) {
                $swm_main_title = sprintf( esc_html__( 'Archive: %s', 'studio-fifty' ), get_the_date('Y') );
            }
            elseif ( is_author() ) {
                $swm_main_title = esc_html__( 'Author Archives', 'studio-fifty' );
            }
            elseif ( is_tag() || is_category() ) {
                $swm_main_title =  $wp_query->queried_object->name;
            }
            else {
                $swm_main_title = single_term_title( '', false );
            }
        }
        elseif ( is_404() ) {
            $swm_main_title = esc_html__( 'Error Page', 'studio-fifty' );
        }
        elseif ( is_page_template('template-blog.php') ) {
            $swm_main_title = get_the_title();
        }
        elseif ( is_single() ) {

            $swm_get_post_type = get_post_type();

            if ( $swm_get_post_type == 'post' ) {
                $swm_main_title = esc_html__( 'Blog', 'studio-fifty' );
            } else {
                $swm_main_title = get_the_title();
            }

        }
        elseif ( is_page() ) {
            $swm_main_title = get_the_title();
        }
        elseif ( is_search() ) {
            $swm_main_title = esc_html__( 'Search', 'studio-fifty' );
        }
        elseif ( is_home() ) {
            $swm_main_title = esc_html__( 'Blog', 'studio-fifty' );
        }

        if ( SWM_WOOCOMMERCE_IS_ACTIVE ) {

            if ( is_shop() ) {
                $swm_main_title = woocommerce_page_title($echo = false);
            }
            elseif ( is_product_category() ) {
                $swm_main_title = single_cat_title('',false);
            }
            elseif ( is_product_tag() ) {
                $swm_main_title = sprintf( esc_html__( '%s', 'studio-fifty' ), single_tag_title('',false) );
            }

        }

        return apply_filters( 'swm_get_main_titles_text', $swm_main_title );

    }

}

if (!function_exists('swm_main_titles')) {
    function swm_main_titles() {

        $output = '';
        $swm_get_main_titles_text = '';
        $swm_get_main_titles_text = swm_get_main_titles_text();

        if ( $swm_get_main_titles_text != '' ) {

            if ( is_page() || is_archive() || is_home() || is_singular( array( 'portfolio' ) ) || is_search() ) {
                $output = '<h1 class="swm-page-title-bar-title swm-heading-text entry-title"><span>' . do_shortcode( wp_kses( $swm_get_main_titles_text,swm_kses_allowed_text() ) ) . '</span></h1><div class="clear"></div>';
            } else {
                $output = '<div class="swm-page-title-bar-title swm-heading-text entry-title"><span>' . do_shortcode( wp_kses( $swm_get_main_titles_text,swm_kses_allowed_text() ) ) . '</span></div><div class="clear"></div>';
            }

        }

        return $output;

    }
}

/* ----------------------------------------------------------------------------------------
    KSES allowed tags
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_allowed_attr')) {
    function swm_allowed_attr() {
        return array( 'class' => true,'style' => true,'id'=> true );
    }
}

if (!function_exists('swm_allowed_anchor_tag_attr')) {
    function swm_allowed_anchor_tag_attr() {
        return array(
            'href' => true,
            'title' => true,
            'class' => true,
            'style' => true,
            'target' => true,
            'data-filter' => true,
            'rel' => true
        );
    }
}

if (!function_exists('swm_kses_allowed_textarea')) {
    function swm_kses_allowed_textarea() {

        $output = '';

        $output = array(
            'a' => swm_allowed_anchor_tag_attr(),
            'abbr' => array( 'title' => true ),
            'acronym' => array('title' => true, ),
            'b' => array(),
            'blockquote' => array(  'cite' => true,
                                    'class' => true,
                                    'style' => true,
                                    'id'=> true
                                ),
            'cite' => swm_allowed_attr(),
            'code' => array(),
            'del' => array('datetime' => true, ),
            'em' => swm_allowed_attr(),
            'i' => swm_allowed_attr(),
            'q' => array('cite' => true, ),
            'iframe' => array(  'class' => true,
                                'style' => true,
                                'id'=> true,
                                'src' => true,
                                'title' => true,
                                'byline' => true,
                                'portrait' => true,
                                'color' => true,
                                'width' => true,
                                'height' => true,
                                'frameborder' => true,
                                'webkitAllowFullScreen' => true,
                                'mozallowfullscreen' => true,
                                'allowFullScreen' => true,
                                'allowfullscreen' => true
                            ),
            'strike' => array(),
            'strong' => array(),
            'h1' => swm_allowed_attr(),
            'h2' => swm_allowed_attr(),
            'h3' => swm_allowed_attr(),
            'h4' => swm_allowed_attr(),
            'h5' => swm_allowed_attr(),
            'h6' => swm_allowed_attr(),
            'p' => swm_allowed_attr(),
            'ul' => swm_allowed_attr(),
            'ol' => swm_allowed_attr(),
            'li' => swm_allowed_attr(),
            'div' => swm_allowed_attr(),
            'span' => swm_allowed_attr(),
            'small' => swm_allowed_attr(),
            'br' => swm_allowed_attr(),
            'img' => array(
                            'src' => true,
                            'class' => true,
                            'style' => true,
                            'id'=> true,
                            'alt'=> true,
                            'title'=> true,
                             'width' => true,
                             'height'=> true
                        )
            );

        return apply_filters( 'swm_kses_allowed_textarea', $output );
    }
}

// KSES for title or short sentenses ----------------------------------------------------------------------------------------

if (!function_exists('swm_kses_allowed_text')) {
    function swm_kses_allowed_text() {

        $output = '';

        $output = array(
            'a' => swm_allowed_anchor_tag_attr(),
            'abbr' => array('title' => true, ),
            'b' => swm_allowed_attr(),
            'cite' => swm_allowed_attr(),
            'em' => swm_allowed_attr(),
            'i' => swm_allowed_attr(),
            'strike' => array(),
            'strong' => array(),
            'span' => swm_allowed_attr(),
            'small' => swm_allowed_attr(),
            'div' => swm_allowed_attr(),
            'br' => swm_allowed_attr()
            );

        return apply_filters( 'swm_kses_allowed_text', $output );
    }
}

/* ----------------------------------------------------------------------------------------
    Related Posts
---------------------------------------------------------------------------------------- */

if( ! function_exists( 'swm_get_related_posts' ) ) {
    function swm_get_related_posts( $post_id, $number_posts = -1 ) {

        $query = new WP_Query();
        $args = '';

        if( $number_posts == 0 ) {
            return $query;
        }

        $args = wp_parse_args( $args, array(
            'category__in'          => wp_get_post_categories( $post_id ),
            'ignore_sticky_posts'   => 0,
            'meta_key'              => '_thumbnail_id',
            'posts_per_page'        => $number_posts,
            'post__not_in'          => array( $post_id ),
        ));

        $query = new WP_Query( $args );

        return apply_filters( 'swm_get_related_posts', $query );

    }
}

/* ----------------------------------------------------------------------------------------
    GET COMMENTS NUMBER
---------------------------------------------------------------------------------------- */

if( ! function_exists( 'swm_get_comments_number' ) ) {
    function swm_get_comments_number() {

        $swm_num_comments = get_comments_number($echo="");

        if ( $swm_num_comments == 0 ) {
            $output =  esc_html__('0 Comments','studio-fifty');
        } elseif ( $swm_num_comments > 1 ) {
            $output =  $swm_num_comments . esc_html__(' Comments','studio-fifty');
        } else {
            $output =  esc_html__('1 Comment','studio-fifty');
        }

        if ($echo == false) {
            return apply_filters( 'swm_get_comments_number', $output );
        } else {
            echo apply_filters( 'swm_get_comments_number', $output );
        }

    }
}

/* ----------------------------------------------------------------------------------------
    Template Part
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_get_template_part' ) ) {
    function swm_get_template_part( $module, $template, $params = array() ) {
        //HTML Content from template
        $html          = '';
        $template_path = SWM_PARTS_ROOT_DIR . $module;

        $temp = $template_path . '/' . $template;
        if ( is_array( $params ) && count( $params ) ) {
            extract( $params ); // @codingStandardsIgnoreLine
        }

        $template = '';

        if ( ! empty( $temp ) ) {
            $template = $temp . '.php';
        }

        if ( $template ) {
            ob_start();
            include( $template ); // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
            $html = ob_get_clean();
        }

        return $html;
    }
}

/* ----------------------------------------------------------------------------------------
    SVG Icons
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_render_svg_icon' ) ) {
    function swm_render_svg_icon( $name, $class_name = '' ) {
        echo swm_get_svg_icon( $name, $class_name ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
    }
}

if ( ! function_exists( 'swm_get_svg_icon' ) ) {
    function swm_get_svg_icon( $name, $class_name = '' ) {
        $class = 'swm-svg--' . $name;
        $class = isset( $class_name ) && ! empty( $class_name ) ? $class . ' ' . $class_name : $class;

        $html = swm_get_template_part( 'svg', $name, array( 'class' => $class ) );

        // remove white spaces from loaded svg markup
        $html = preg_replace( '~>\s+<~', '><', $html );
        $html = trim( $html );

        return apply_filters( 'swm_filter_svg_icon', $html );
    }
}

/* ----------------------------------------------------------------------------------------
    Pagination
---------------------------------------------------------------------------------------- */

// Standard Pagination (1,2,3,4)
if ( !function_exists( 'swm_standard_pagination' ) ) {
    function swm_standard_pagination($total=null) {

        $swm_arrowNextPrev = swm_get_svg_icon( 'arrow', 'swm-svg-pagination-arrow' );

        global $wp_query;

        $swm_total_page = $wp_query->max_num_pages;
        $swm_big_number = 999999999; // need an unlikely integer
        $output = '';

        if( $swm_total_page > 1 )  {
            $output .= '<div class="swm-pagination-wrap">';
            $output .= '<div class="swm-pagination highlight-text">';

             if( !$current_page = get_query_var('paged') )
                 $current_page = 1;
             if( get_option('permalink_structure') ) {
                 $swm_pagination_format = 'page/%#%/';
             } else {
                 $swm_pagination_format = '&paged=%#%';
             }

            $output .= paginate_links(array(
                'base'          => str_replace( $swm_big_number, '%#%', esc_url( get_pagenum_link( $swm_big_number ) ) ),
                'format'        => $swm_pagination_format,
                'current'       => max( 1, get_query_var('paged') ),
                'total'         => $swm_total_page,
                'mid_size'      => 2,
                'show_all'      => false,
                "add_args"      => false,
                'type'          => 'plain',
                'prev_text'     => $swm_arrowNextPrev,
                'next_text'     => $swm_arrowNextPrev
             ) );

            $output .= '<div class="clear"></div></div></div>';

        }

        echo apply_filters( 'swm_standard_pagination', $output );
    }
}


// Next - Previous Pagination

if ( !function_exists( 'swm_next_prev_links' ) ) {
    function swm_next_prev_links() {

        $output = '';

        $output .= '<div class="alignleft post-prev">
                        '.get_previous_posts_link('&larr; '. esc_html__( 'Prev', 'studio-fifty' ) ).'
                    </div>
                    <div class="alignright post-next">
                        '.get_next_posts_link( esc_html__( 'Next', 'studio-fifty' ) .' &rarr;').'
                    </div>';

        return apply_filters( 'swm_next_prev_links', $output );
    }
}


if ( !function_exists( 'swm_next_prev_pagination' ) ) {
    function swm_next_prev_pagination( $pages = '', $range = 4 ) {
        global $paged;
        $output = '';
        if(empty($paged)) $paged = 1;

        if( $pages == '' ) {
           global $wp_query;
           $pages = $wp_query->max_num_pages;
           if(!$pages) {
               $pages = 1;
           }
        }

        if( 1 != $pages ) {
            $output .= '<div class="swm-next-prev-pagination clear">
                            '.swm_next_prev_links().'
                        </div>';
        }

        echo apply_filters( 'swm_next_prev_pagination', $output );
    }
}


if ( !function_exists( 'swm_pagination' ) ) {
    function swm_pagination($pagination_style) {

        if ( $pagination_style == 'next-prev' ) {
            swm_next_prev_pagination();
        } else {
            swm_standard_pagination();
        }
    }
}

/* ----------------------------------------------------------------------------------------
    Post Single Next Previous Pagination
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_content_pagination_menu')) {
    function swm_content_pagination_menu() {

    $output = '';

    $args = array(
        'before'           => '<div class="clear"></div><div class="swm-pagination-menu">',
        'after'            => '<div class="clear"></div></div>',
        'link_before'      => '<span class="wp_link_pages_custom">',
        'link_after'       => '</span>',
        'next_or_number'   => 'number',
        'nextpagelink'     => esc_html__('Next Page ', 'studio-fifty'),
        'previouspagelink' => esc_html__('Previous Page ', 'studio-fifty'),
        'pagelink'         => '%',
        'echo'             => 0
    );

    $args = apply_filters( 'swm_content_pagination_menu_args', $args );

    return wp_link_pages( $args );

    }
}

/* ----------------------------------------------------------------------------------------
    Add sections to the headers list
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_mk_list_sections_styles' ) ) {
    function swm_mk_list_sections_styles( $type, $order='ID', $list = array() ) {
            $get_list = array();
            $args = array(
                'post_type'    => 'cpt_sections',
                'meta_key'     => 'mk_section_type',
                'meta_value'   => $type,
                'orderby'      => $order,
                'order'        => 'asc',
                'not_selected' => false,
                'return'       => 'id',
                'ignore_sticky_posts' => true,
                'posts_per_page'   => 1000,
                'suppress_filters' => false,
            );
            $posts = get_posts( $args );
            if ( is_array( $posts ) && count( $posts ) > 0 ) {
                foreach ( $posts as $post ) {
                    $get_list[ $post->ID ] = $post->post_title;
                }
            }

            $new_list = array();
            foreach ( $get_list as $id => $title ) {
                if ( 'none' != $id ) {
                    $new_list[ $type . '-custom-' . intval( $id ) ] = $title;
                }
            }
            $list = array_merge( $list,$new_list );

        return $list;
    }
}

// Return id of the custom header or footer for current mode
if ( ! function_exists( 'swm_mk_get_custom_section_id' ) ) {
    function swm_mk_get_custom_section_id( $type, $section_style = '' ) {
        $section_id = 0;
        $section_id = str_replace( "{$type}-custom-", '', $section_style );
        $section_id = swm_mk_parse_obj_id($section_id);
        $section_id = apply_filters( 'swm_filter_get_translated_section', $section_id );
        return $section_id;
    }
}

/* ----------------------------------------------------------------------------------------
    Multi language support for sections
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_get_translated_post_id')) {
    function swm_get_translated_post_id($post_id) {
        if ( function_exists( 'pll_get_post' ) ) {
                $translation_post_id = pll_get_post( $post_id );

                if ( null === $translation_post_id ) {
                    return $post_id;                                // the current language is not defined yet
                } elseif ( false === $translation_post_id ) {
                    return $post_id;                                // no translation yet
                } elseif ( $translation_post_id > 0 ) {
                    return $translation_post_id;                    // return translated post id
                }
            }
            return $post_id;
    }
}

/* ----------------------------------------------------------------------------------------
    Remove Elementor plugin fontawesome icons
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_dequeue_elementor_extra_styles' ) ) {
    function swm_dequeue_elementor_extra_styles() {
        wp_deregister_style('elementor-icons-fa-shared-0');
        wp_deregister_style('elementor-icons-fa-solid');
        wp_deregister_style('elementor-icons-fa-regular');
        wp_deregister_style('elementor-icons-fa-brands');
    }
}
add_action('elementor/frontend/after_register_styles','swm_dequeue_elementor_extra_styles', 20);


/* ----------------------------------------------------------------------------------------
    Body Font Weight
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_get_selector_font_all_weight' ) ) {
    function swm_get_selector_font_all_weight($selector) {

        $swm_get_selector_font_all_weight = 'italic';

        if ( get_theme_mod( 'swm_'.$selector.'_font_weight_light', 'on' ) == 'on' ) {
            $swm_get_selector_font_all_weight .= ',300,300italic';
        }

        if ( get_theme_mod( 'swm_'.$selector.'_font_weight_medium', 'on' ) == 'on' ) {
            $swm_get_selector_font_all_weight .= ',500,500italic';
        }

        if ( get_theme_mod( 'swm_'.$selector.'_font_weight_semi_bold', 'on' ) == 'on' ) {
            $swm_get_selector_font_all_weight .= ',600,600italic';
        }

        if ( get_theme_mod( 'swm_'.$selector.'_font_weight_bold', 'on' ) == 'on' ) {
            $swm_get_selector_font_all_weight .= ',700,700italic';
        }

        return $swm_get_selector_font_all_weight;
    } // End function
} // End if

/* ----------------------------------------------------------------------------------------
    Post Page Layout
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_page_post_layout_type' ) ) {
    function swm_page_post_layout_type() {

        // Vars
        $swm_page_post_layout_type_class = 'layout-sidebar-right';
        $swm_get_post_types              = get_post_types( '', 'names' );
        $swm_blog_page_layout_type       = get_theme_mod( 'swm_blog_page_layout', 'layout-sidebar-right' );
        $swm_content_layout              = get_theme_mod( 'swm_content_layout', 'layout-full-width' );
        $swm_meta_content_layout         = 'layout-full-width';
        $swm_meta_content_layout         = get_post_meta( swm_get_queried_object_id(), 'swm_meta_content_layout', true );
        $swm_wc_shop_layout              = get_theme_mod( 'swm_wc_shop_layout', 'layout-sidebar-right' );

        // Loop through post types
        if ( is_single() || is_page() ) {

                if ( $swm_meta_content_layout !== '' && $swm_meta_content_layout !== 'default' ) {
                    $swm_page_post_layout_type_class = $swm_meta_content_layout;
                } else {
                    $swm_page_post_layout_type_class = $swm_content_layout;
                }
            }

        if ( is_archive() || is_author() || is_tag() ) {
            $swm_page_post_layout_type_class = $swm_blog_page_layout_type;
        }

        if ( SWM_WOOCOMMERCE_IS_ACTIVE ) {
            if ( is_shop() ) {
                $swm_page_post_layout_type_class = $swm_wc_shop_layout;
            }
        }

        return $swm_page_post_layout_type_class;

    } // End function
} // End if

/* ----------------------------------------------------------------------------------------
    Comments Listing
---------------------------------------------------------------------------------------- */

if ( !function_exists( 'swm_comment_listing' ) ) {

    function swm_comment_listing( $comment, $args, $depth ) {

        $GLOBALS['comment'] = $comment;

        $swm_avatar_size = '224';

        $swm_comment_reply_icon = is_rtl() ? 'mail-forward' : 'reply';

        switch ( $comment->comment_type ) :
            case 'comment' : ?>

                <li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
                    <article id="comment-<?php comment_ID(); ?>" class="comment-body swm-anim">

                        <div class="comment-content">
                            <div class="comment_area">
                                <div class="comment-content">

                                    <div class="comment-avatar">
                                        <span><?php echo get_avatar( $comment, $swm_avatar_size ); ?></span>
                                        <div class="clear"></div>
                                    </div>

                                    <div class="comment-postinfo">

                                        <div class="comment-title-section">
                                            <h5 class="comment-author swm-color-headings"><?php printf( esc_html__( '%s', 'studio-fifty' ), sprintf( '%s ', get_comment_author_link()." " ) );  ?></h5>
                                            <div class="swm-comment-reply">
                                                <div class="swm-comment-reply-btn swm-heading-text"><?php comment_reply_link(
                                                        array_merge( $args, array(
                                                            'depth' => $depth,
                                                            'max_depth' => $args['max_depth'],
                                                            'reply_text' => swm_get_svg_icon( 'arrow-alt', 'swm-comment-reply-btn-arrow' ) . 'Reply'
                                                        ) )
                                                    ); ?></div>
                                            </div>
                                        </div>

                                        <div class="comment-text">
                                            <?php comment_text();
                                            if ( $comment->comment_approved == '0' ) : ?>
                                                <p><em><?php echo esc_html__( 'Your comment is awaiting moderation.', 'studio-fifty' ); ?></em></p>
                                            <?php
                                            endif; ?>
                                        </div>

                                        <div class="comment-date"><?php echo get_comment_date(get_option('date_format')); ?></div>

                                        <?php edit_comment_link( esc_html__( ' (Edit)', 'studio-fifty' ), ' ' );   ?>

                                        <div class="clear"></div>

                                    </div> <!-- end .comment-postinfo -->

                                    <div class="clear"></div>

                                </div> <!-- end comment-content-->


                                <div class="clear"></div>

                            </div> <!-- end comment_area-->
                        </div>
                        <div class="clear"></div>

                    </article> <!-- end comment-body -->
                    <div class="clear"></div>

                <?php
                break;
            case 'pingback'  :
            case 'trackback' : ?>

                <li class="post pingback">
                <p><?php echo esc_html__( 'Pingback:', 'studio-fifty' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( esc_html__('(Edit)', 'studio-fifty'), ' ' ); ?></p>
                <?php
                break;
        endswitch;
    }
}

/* ----------------------------------------------------------------------------------------
    Get Queried Object ID
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_get_queried_object_id')) {
    function swm_get_queried_object_id() {
        $swm_get_queried_object_id = get_queried_object_id();
        return $swm_get_queried_object_id;
    }
}


/* ----------------------------------------------------------------------------------------
    Get Post Metas
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_get_post_metas')) {
    function swm_get_post_metas($field,$default=true) {

        $swm_get_post_metas = get_post_meta( swm_get_queried_object_id(), $field, $default );

        return $swm_get_post_metas;
    }
}

/* ----------------------------------------------------------------------------------------
    Get Customizer / Meta Value
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_customizer_metabox_onoff')) {
    function swm_customizer_metabox_onoff($customizer_option,$metabox_option,$customizer_default_value='default',$metabox_option_default_value='') {

        $swm_cm_on_off   = '';
        $swm_cm_on_off   = get_theme_mod( $customizer_option,$customizer_default_value );
        $swm_meta_on_off = $metabox_option_default_value;
        $swm_meta_on_off = get_post_meta( swm_get_queried_object_id(), $metabox_option, true );

        if ( !empty( $swm_meta_on_off ) && $swm_meta_on_off != 'default' ) {
            $swm_cm_on_off = $swm_meta_on_off;
        }

        return $swm_cm_on_off;

    }
}

/* ----------------------------------------------------------------------------------------
    Sanitization Image, Color, URL, Number, Text
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_sanitize_image' ) ) {
    function swm_sanitize_image( $image ) {
        $cust_all_images = array(
            'jpg|jpeg|jpe' => 'image/jpeg',
            'gif'          => 'image/gif',
            'png'          => 'image/png',
            'bmp'          => 'image/bmp',
            'webp'         => 'image/webp',
            'svg'          => 'image/svg',
            'tif|tiff'     => 'image/tiff',
            'ico'          => 'image/x-icon'
        );

        $file = wp_check_filetype( $image, $cust_all_images );
        return ( $file['ext'] ? $image : '' );
    }
}

if ( ! function_exists( 'swm_sanitize_font' ) ) {
    function swm_sanitize_font( $font ) {
        $mimes = array(
            'ttf'   => 'font/ttf',
            'woff'  => 'font/woff',
            'woff2' => 'font/woff2',
        );

        $file = wp_check_filetype( $font, $mimes );
        return ( $file['ext'] ? $font : '' );
    }
}

if ( ! function_exists( 'swm_sanitize_color' ) )  { function swm_sanitize_color( $hex_color ) { return sanitize_hex_color( $hex_color ); } }
if ( ! function_exists( 'swm_sanitize_url' ) )    { function swm_sanitize_url( $url )         { return esc_url_raw( $url ); } }
if ( ! function_exists( 'swm_sanitize_slider' ) ) { function swm_sanitize_slider( $number )   { return floatval( $number ); } }
if ( ! function_exists( 'swm_sanitize_text' ) )   { function swm_sanitize_text( $html )       { return esc_html( $html ); } }
if ( ! function_exists( 'swm_sanitize_default' ) )   { function swm_sanitize_default( $html )       { return $html; } }

if ( ! function_exists( 'swm_sanitize_multi_check' ) )     {
    function swm_sanitize_multi_check( $values ) {
        $swm_multi_check_values = !is_array( $values ) ? explode( ',', $values ) : $values;
        return !empty( $swm_multi_check_values ) ? array_map( 'sanitize_text_field', $swm_multi_check_values ) : array();
    }
}

if ( ! function_exists( 'swm_get_sanitize_callback' ) )     {
    function swm_get_sanitize_callback( $type ) {
       if ( $type === 'slider'
        || $type === 'text'
        || $type === 'color'
        || $type === 'image'
        || $type === 'url'
        || $type === 'multi-check'
        || $type === 'fonts') {
            return 'swm_sanitize_' . $type;
       } elseif ( $type === 'textarea' ) {
            return 'wp_kses_post';
       }
    }
}

/* ----------------------------------------------------------------------------------------
    Check current request
---------------------------------------------------------------------------------------- */
if ( ! function_exists( 'swm_is_request' ) ) {
    function swm_is_request( $type ) {
        switch ( $type ) {
            case 'admin':
                return is_admin();
            case 'ajax':
                return wp_doing_ajax();
            case 'frontend':
                return ( ! is_admin() || wp_doing_ajax() );
        }
    }
}

/* ----------------------------------------------------------------------------------------
    Theme Panel Options
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_get_ts_option' ) ) :
    function swm_get_ts_option( $name, $default = false ) {
        $config = get_option( 'mk_theme_settings' );

        if ( ! isset( $config['id'] ) ) {
            return $default;
        }

        $options = get_option( $config['id'] );

        if ( isset( $options[$name] ) ) {
            return $options[$name];
        }

        return $default;
    }
endif;

/* ----------------------------------------------------------------------------------------
    Get Widget Areas
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_get_widget_areas' ) ) {
    function swm_get_widget_areas() {
        global $wp_registered_sidebars;
        $widgets_areas = array();
        if ( ! empty( $wp_registered_sidebars ) ) {
            foreach ( $wp_registered_sidebars as $widget_area ) {
                $name = isset ( $widget_area['name'] ) ? $widget_area['name'] : '';
                $id = isset ( $widget_area['id'] ) ? $widget_area['id'] : '';
                if ( $name && $id ) {
                    $widgets_areas[$id] = $name;
                }
            }
        }
        return $widgets_areas;
    }
}

/* ----------------------------------------------------------------------------------------
    Sticky Header Functions
---------------------------------------------------------------------------------------- */

if ( ! function_exists( 'swm_sticky_header_section' ) ) {
    function swm_sticky_header_section($header_id) {

        $swm_header_sticky_scroll_up_down = ( get_theme_mod('swm_custom_sticky_header_scroll_up','off') == 'on' ) ? 'swm-sticky-scoll-up' : 'swm-sticky-scoll-down';

        echo '<header class="swm_header_sticky_section ' . esc_attr($swm_header_sticky_scroll_up_down) . '" id="swm-sticky-header">
                    ' . do_action( 'swm_action_show_section', $header_id ) . '
                </header>';
    }
}

/* ----------------------------------------------------------------------------------------
    Show Header
---------------------------------------------------------------------------------------- */

if (!function_exists('swm_show_the_header')) {
    function swm_show_the_header($meta_field,$default=true) {
        $swm_show_the_header = 'on';
        $swm_meta_header_on  = swm_get_post_metas($meta_field,$default);

        if ( !empty($swm_meta_header_on) && isset($swm_meta_header_on) ) {
            $swm_show_the_header = $swm_meta_header_on;
        }

        return $swm_show_the_header;
    }
}