<?php

if ( ! class_exists( 'Studio_Fifty_Filters' ) ) {
    /**
     * Theme class for WordPress filters
     */
    class Studio_Fifty_Filters {
        private static $instance;

        public function __construct() {
            add_filter( 'use_default_gallery_style', '__return_false' );
            add_filter('body_class',                   [ $this, 'body_classes' ] );
            add_filter( 'excerpt_length',              [ $this, 'excerpt_length' ], 999 );
            add_filter( 'get_search_form',             [ $this,'get_search_form' ] );
            add_filter( 'the_password_form',           [ $this,'password_form' ] );
            add_filter( 'img_caption_shortcode_width', [ $this,'slim_img_caption_shortcode' ] );
            add_filter( 'comment_form_defaults',       [ $this,'comment_textarea_placeholder' ] );
            add_filter( 'comment_form_default_fields', [ $this,'comment_form_fields' ] );
            add_filter( 'nav_menu_css_class',          [ $this,'add_active_class' ], 10, 2 );
            add_filter( 'nav_menu_css_class',          [ $this,'remove_cpt_blog_class' ], 10, 3 );
            add_filter('widget_tag_cloud_args',        [ $this,'tag_cloud_fonts' ], 90);
            add_filter('woocommerce_product_tag_cloud_widget_args', [ $this,'tag_cloud_fonts' ],20);
        }

        public static function get_instance() {
            if ( is_null( self::$instance ) ) {
                self::$instance = new self();
            }
            return self::$instance;
        }

        /* Excerpt Limit */
        public function excerpt_length( $length ) {
            return intval(get_theme_mod('swm_excerpt_length',40));
        }

        /* Search Form */
        public function get_search_form( $form ) {

            $swm_search_keywords = get_theme_mod( 'swm_header_search_placeholder_text','Keywords...' );
            $swm_search_keywords = swm_translate_theme_mod( 'swm_header_search_placeholder_text', $swm_search_keywords );  // Translate the theme option

            $swm_form_content = '<form method="get" action="'.esc_url(home_url('/')).'" class="swm-search-form">
                    <div class="swm-search-form_inner">
                        <input type="text" placeholder="'.esc_attr($swm_search_keywords).'" name="s" class="swm-search-form-input secondary highlight-text" autocomplete="off" />
                        <button type="submit" class="swm-search-button swm-anim swm-color-headings"><span class="swm-search-icon"></span></button>
                        <div class="clear"></div>
                    </div>
                </form>';

            return $swm_form_content;
        }

        /* Password Form */
        public function password_form() {
            global $post;
            $password_form_label = 'pwbox-'.( empty( $post->ID ) ? rand() : $post->ID );

            $output = '<form action="' . esc_url( home_url( 'wp-login.php?action=postpass', 'login_post' ) ) . '" class="post-password-form" method="post">
            <p>' . esc_html__( 'This content is password protected. To view it please enter your password below:','studio-fifty' ) . '</p>
            <p><label for="' . $password_form_label . '">' . esc_html__( 'Password:','studio-fifty' ) . ' <input name="post_password" id="' . $password_form_label . '" type="password" size="20" /></label> <input type="submit" name="Submit" value="' . esc_attr__( 'Submit','studio-fifty' ) . '" /></p></form>
            ';

            return $output;
        }

        /* Remove Extra 10px margin in WordPress "caption" shortcode */
        public function slim_img_caption_shortcode( $caption_width ) {
            return 0;
        }

        /* Body Class Filter */
        public function body_classes($body_classes) {

            $swm_blog_page_layout = get_theme_mod('swm_blog_page_layout','layout-sidebar-right');

            if ( is_single() ) {

                $body_classes[] = get_post_meta( swm_get_queried_object_id(), 'swm_meta_content_layout', true ).'_page';

                $swm_blog_single_layout = get_theme_mod('swm_blog_single_layout','standard');
                $swm_meta_blog_single_layout = get_post_meta( swm_get_queried_object_id(), 'swm_meta_blog_single_layout', true );

                if ( 'default' !== $swm_meta_blog_single_layout ) {
                    $swm_blog_single_layout = $swm_meta_blog_single_layout;
                }

                $body_classes[] = 'single-' . $swm_blog_single_layout;

            } else {
                $body_classes[] = $swm_blog_page_layout.'_page';
            }

            if ( get_theme_mod('swm_page_preloader_on','off' ) === 'on' ) {

                $swm_show_page_preloader    = 'on';
                $swm_meta_page_preloader_on = get_post_meta( swm_get_queried_object_id(), 'swm_meta_page_preloader_on', true );
                $swm_page_preloader_skin    = get_theme_mod('swm_page_preloader_skin','light');

                if ( !empty($swm_meta_page_preloader_on) && isset($swm_meta_page_preloader_on) ) {
                    $swm_show_page_preloader  = $swm_meta_page_preloader_on;
                    $swm_page_preloader_skin  = get_post_meta( swm_get_queried_object_id(), 'swm_meta_page_preloader_skin', true );
                }

                if ( $swm_show_page_preloader == 'on' && $swm_page_preloader_skin == 'dark' ) :
                    $body_classes[] = 'swm-page-preloader-dark';
                endif;

            }

            if ( swm_customizer_metabox_onoff('swm_page_preloader_on','swm_meta_page_preloader_on','off','default') == 'on' ) {

                $swm_page_preloader_skin        = get_theme_mod('swm_page_preloader_skin','light');
                $swm_meta_page_preloader_skin   = get_post_meta( swm_get_queried_object_id(), 'swm_meta_page_preloader_skin', true );
                $swm_meta_page_preloader_on = get_post_meta( swm_get_queried_object_id(), 'swm_meta_page_preloader_on', true );

                if ( !empty($swm_meta_page_preloader_on) && isset($swm_meta_page_preloader_on) && $swm_meta_page_preloader_on != 'default' ) {
                    if ( !empty($swm_meta_page_preloader_skin) && isset($swm_meta_page_preloader_skin) ) {
                        $swm_page_preloader_skin  = $swm_meta_page_preloader_skin;
                    }
                }

                if ( $swm_page_preloader_skin == 'dark' ) :
                    $body_classes[] = 'swm-page-preloader-dark';
                endif;
            }

            // sticky header
            if ( get_theme_mod('swm_custom_sticky_header_mobile_on','on') == 'on') {
                $body_classes[] = 'swm-hide-sticky-header-mobile';
            }

            // woocommerce
            if ( SWM_WOOCOMMERCE_IS_ACTIVE && is_singular('product') ) {
                if ( get_theme_mod('swm_wc_single_gallery_position','bottom') != 'bottom') {
                    $body_classes[] = 'product-thumb-side';
                    $body_classes[] = 'product-thumb-side-' . get_theme_mod('swm_wc_single_gallery_position','bottom');
                } else {
                    $body_classes[] = 'product-thumb-bottom';
                }
            }
            return $body_classes;

        }

        /* Comment Form Customization */
        public function comment_textarea_placeholder( $args ) {
            $args['comment_field'] = str_replace( 'textarea', 'textarea placeholder="' . esc_html__( 'Your Comment *', 'studio-fifty' ) . '"', $args['comment_field'] );
            return $args;
        }

        public function comment_form_fields( $fields ) {
            foreach( $fields as &$field ) {

                $field = str_replace( 'id="author"', 'id="author" placeholder="' . esc_html__( 'Your Name *', 'studio-fifty' ) . '"', $field );
                $field = str_replace( 'id="email"', 'id="email" placeholder="' . esc_html__( 'Your Email *', 'studio-fifty' ) . '"', $field );
                $field = str_replace( 'id="url"', 'id="url" placeholder="' . esc_html__( 'Website', 'studio-fifty' ) . '"', $field );
            }
            return $fields;
        }

        /* Add Active link custom class */
        public function add_active_class($classes, $item) {

            if( in_array( 'current-menu-item', $classes ) ||
                in_array( 'current-menu-ancestor', $classes ) ||
                in_array( 'current-menu-parent', $classes ) ||
                in_array( 'current_page_parent', $classes ) ||
                in_array( 'current_page_ancestor', $classes ) ) {
                $classes[] = "swm-m-active";
            }

            return $classes;
        }

        /* Remove current_page_parent nav class from blog index when in Custom Post Types */
        public function remove_cpt_blog_class( $classes, $item, $args ) {
            if( !is_singular( 'post' ) AND !is_category() AND !is_tag() AND !is_date() ):
                $blog_page_id = intval( get_option( 'page_for_posts' ) );
                if( $blog_page_id != 0 AND $item->object_id == $blog_page_id )
                    unset( $classes[ array_search( 'current_page_parent', $classes ) ] );
            endif;
            return $classes;
        }

        // tag cloud font size
        public function tag_cloud_fonts($args = array()) {
            $args['smallest'] = 17;
            $args['largest'] = 17;
            $args['unit'] = 'px';
            return $args;
        }

    }

    Studio_Fifty_Filters::get_instance();
}