<?php
if ( ! class_exists( 'Swm_WooCommerce' ) ) {
    class Swm_WooCommerce {
        private static $instance;

        public function __construct() {
            $this->include_files();
            add_action( 'before_woocommerce_init', array( $this, 'init' ) );
            add_action( 'wp_enqueue_scripts', array($this,'load_style_scripts') );
        }

        public static function get_instance() { if ( is_null( self::$instance ) ) {self::$instance = new self(); } return self::$instance; }

        function include_files() {
            include_once SWM_WOOCOMMERCE . 'shop-list.php';
            include_once SWM_WOOCOMMERCE . 'shop-single.php';
        }

        public function load_style_scripts(){
            wp_enqueue_style( 'swm-woo-styles', SWM_THEME_DIR . '/woocommerce/woo-styles-min.css', '', SWM_THEME_VERSION );
            wp_enqueue_script( 'swm-woo-scripts', SWM_THEME_DIR . '/woocommerce/woo-scripts-min.js', ['jquery'],SWM_THEME_VERSION, TRUE );
        }

        function init() {
            // Adds theme supports

            add_theme_support('woocommerce');

            add_filter( 'woocommerce_gallery_thumbnail_size', function( $size ) {
                return get_theme_mod('swm_wc_single_gallery_img_width','thumbnail');
            });

            add_theme_support( 'wc-product-gallery-slider' );    // Enable built-in image slider on the single product page
            add_theme_support( 'wc-product-gallery-zoom' );      // Enable built-in image zoom on the single product page
            add_theme_support( 'wc-product-gallery-lightbox' );  // Enable built-in image lightbox on the single product page
            add_filter( 'woocommerce_allow_marketplace_suggestions', '__return_false' );  // Disable WooCommerce ads

            add_filter( 'woocommerce_product_tag_cloud_widget_args', 'swm_woocommerce_tag_cloud_widget' );

            $this->unset_templates_modules();
            $this->shop_list();
            $this->shop_single();
            $this->set_default_layout();
            $this->change_templates_position();
            $this->override_templates();

        }

        // Unset default WooCommerce templates modules

        function unset_templates_modules() {
            // Remove main shop holder
            remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper' );
            remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end' );

            // Remove breadcrumbs
            remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

            // Remove sidebar
            remove_action( 'woocommerce_sidebar', 'woocommerce_get_sidebar' );

            // Remove product link on list
            remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open' );
            remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
        }

        function shop_list() {

            // Define the loop_shop_columns callback
            add_filter( 'loop_shop_columns', 'swm_filter_loop_shop_columns', 10, 1 );

            // set products per page
            add_filter('loop_shop_per_page', 'swm_loop_shop_per_page');

            // product list - add custom div
            add_action ( 'woocommerce_before_shop_loop_item', 'swm_wc_before_shop_loop_item');
            add_action ( 'woocommerce_after_shop_loop_item', 'swm_wc_after_shop_loop_item');

            // Add additional tags around results and ordering
            // permission 15 is set because wc_print_notices hook is added on 10
            add_action( 'woocommerce_before_shop_loop', 'swm_add_results_and_ordering_holder', 15 );
            // permission 40 is set because woocommerce_catalog_ordering hook is added on 30
            add_action( 'woocommerce_before_shop_loop', 'swm_add_results_and_ordering_holder_end', 40 );
        }

        function shop_single() {

            //gallery thumbnail count
            add_filter ( 'woocommerce_product_thumbnails_columns', 'swm_woo_product_thumbnails_columns' );

            // Override related products args
            add_filter( 'woocommerce_output_related_products_args', 'swm_woo_single_related_product_list_columns' );

            // Override upsell products args
            add_filter( 'woocommerce_upsell_display_args', 'swm_woocommerce_upsell_display_args' );

            // Override cross sells products args
            add_filter( 'woocommerce_cross_sells_columns', 'swm_cross_sells_columns' );
            add_filter( 'woocommerce_cross_sells_total', 'swm_cross_sells_total' );

            // Add placeholders in review form
            add_filter( 'woocommerce_product_review_comment_form_args', 'swm_wc_product_review_comment' );
        }

        function set_default_layout() {

            // Add additional tags around product list item image
            add_action( 'woocommerce_before_shop_loop_item_title', 'swm_add_product_list_item_image_holder', 5 ); // permission 5 is set because woocommerce_show_product_loop_sale_flash hook is added on 10
            add_action( 'woocommerce_before_shop_loop_item_title', 'swm_add_product_list_item_image_holder_end', 30 ); // permission 30 is set because woocommerce_template_loop_product_thumbnail hook is added on 10

            // Add additional tags around content inside product list item image
            add_action( 'woocommerce_before_shop_loop_item_title', 'swm_add_product_list_item_additional_image_holder', 15 ); // permission 15 is set because woocommerce_template_loop_product_thumbnail hook is added on 10
            add_action( 'woocommerce_before_shop_loop_item_title', 'swm_add_product_list_item_additional_image_holder_end', 25 ); // permission 25 is set because swm_add_product_list_item_image_holder_end hook is added on 30

            // Change add to cart position on product list
            remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 ); // permission 10 is default
            add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_add_to_cart', 20 ); // permission 20 is set because swm_add_product_list_item_additional_image_holder hook is added on 15

            // Add additional tags around product list item content
            add_action( 'woocommerce_shop_loop_item_title', 'swm_add_product_list_item_content_holder', 5 ); // permission 5 is set because woocommerce_template_loop_product_title hook is added on 10
            add_action( 'woocommerce_after_shop_loop_item', 'swm_add_product_list_item_content_holder_end', 20 ); // permission 30 is set because woocommerce_template_loop_add_to_cart hook is added on 10

            // Add product categories on list
            add_action( 'woocommerce_shop_loop_item_title', 'swm_add_product_list_item_categories', 10); // permission 8 is set to be before woocommerce_template_loop_product_title hook it's added on 10

            remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 ); // permission 10 is default

            // Add additional tags around product list item image
            add_action( 'woocommerce_before_single_product_summary', 'swm_add_product_single_image_holder', 5 ); // permission 5 is set because woocommerce_show_product_sale_flash hook is added on 10
            add_action( 'woocommerce_before_single_product_summary', 'swm_add_product_single_image_holder_end', 30 ); // permission 30 is set because woocommerce_show_product_images hook is added on 20

            // Override On sale template
            add_filter( 'woocommerce_sale_flash', 'swm_woo_set_sale_flash' );

        }

        function change_templates_position() {
            // Add link at the end of woocommerce_before_shop_loop_item_title ( inside image div )
            add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_open', 28 ); // permission 28 is set because swm_add_product_list_item_image_holder_end is 30
            add_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_link_close', 29 ); // permission 29 is set because swm_add_product_list_item_image_holder_end is 30

            // Add link inside swm_woo_shop_loop_item_title
            add_action( 'swm_woo_product_list_title_tag_link_open', 'woocommerce_template_loop_product_link_open' );
            add_action( 'swm_woo_product_list_title_tag_link_close', 'woocommerce_template_loop_product_link_close' );
        }

        function override_templates() {

            // Disable page heading
            add_filter( 'woocommerce_show_page_title', 'swm_woo_disable_page_heading' );

            // Override product list holder
            add_filter( 'woocommerce_product_loop_start', 'swm_add_product_list_holder' );
            add_filter( 'woocommerce_product_loop_end', 'swm_add_product_list_holder_end' );

            // Override product title
            remove_action( 'woocommerce_shop_loop_item_title', 'woocommerce_template_loop_product_title' );
            // permission 10 is default
            add_action( 'woocommerce_shop_loop_item_title', 'swm_woo_shop_loop_item_title', 10 );
        }
    }

    Swm_WooCommerce::get_instance();
}
